Keywords: figures,movies,index with subindex,_boldface word_ in index,index with _boldface word_,index with _boldface word_ in subentry,double _boldface word_ _boldface word_ in subentry too,index, with comma, and one more

# A Document for Testing DocOnce

Hans Petter Langtangen [1, 2] (`hpl at simula.no`)
Kaare Dump [3]
A. Dummy Author
I. S. Overworked and Outburned [4, 5, 6, 7]
J. Doe (`j_doe at cyberspace.com`)
[1] Center for Biomedical Computing, Simula Research Laboratory
[2] Department of Informatics, University of Oslo
[3] Segfault, Cyberspace
[4] Inst1
[5] Inst2, Somewhere
[6] Third Inst, Elsewhere
[7] Fourth Inst

#### Apr 15, 2021

# Table of contents

| \